<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>RecentFiles</name>
    <message>
        <location filename="../RecentFilesInit.js" line="+51"/>
        <source>&amp;Clear List</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;Limpe a Lista</translation>
    </message>
    <message>
        <source>Load/Save</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Carregue/Grave</translation>
    </message>
    <message>
        <location filename="../RecentFiles.js" line="+35"/>
        <source>Recent Files</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Arquivos Recentes</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>File</source>
        <translation>Ficheiro</translation>
    </message>
    <message>
        <source>Open/Save</source>
        <translation type="vanished">Carregue/Grave</translation>
    </message>
    <message>
        <location filename="../RecentFilesInit.js" line="+10"/>
        <source>Open &amp;Recent</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Abra um Arquivo &amp;Recente</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Recent files history size:</source>
        <translation>Número de arquivos recentes:</translation>
    </message>
</context>
</TS>
